#
# spec file for package mediainfo
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2007-2011 The Packman Team
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mediainfo
Version:        0.7.96
Release:        1.1
Summary:        Supplies technical and tag information about a video or audio file
License:        GPL-2.0+
Group:          Productivity/Multimedia/Other
Url:            http://mediainfo.sourceforge.net/
Source0:        https://sourceforge.net/projects/mediainfo/files/source/mediainfo/%{version}/mediainfo_%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  kdelibs4-core
BuildRequires:  kf5-filesystem
BuildRequires:  libmediainfo-devel = %{version}
BuildRequires:  libtool
BuildRequires:  libzen-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
Provides:       MediaInfo = 0.7.7.8
Obsoletes:      MediaInfo < 0.7.7.8
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?is_opensuse}
BuildRequires:  wxWidgets-devel >= 3
%else
# SLE_12 lacks wxWidgets_3.0-devel
BuildRequires:  wxWidgets-devel < 3
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
%endif

%description
MediaInfo supplies technical and tag information about a video or
audio file.

It reads the following information:
* General: title, author, director, album, track number, date, duration...
* Video: codec, aspect, fps, bitrate...
* Audio: codec, sample rate, channels, language, bitrate...
* Text: language of subtitle
* Chapters: number of chapters, list of chapters

It supports the following containers/codecs:
* Video: MKV, OGM, AVI, DivX, WMV, QuickTime, Real, MPEG-1,
  MPEG-2, MPEG-4, DVD (VOB) (Codecs: DivX, XviD, MSMPEG4, ASP,
  H.264, AVC...)
* Audio: OGG, MP3, WAV, RA, AC3, DTS, AAC, M4A, AU, AIFF
* Subtitles: SRT, SSA, ASS, SAMI

%package gui
Summary:        GUI for mediainfo
Group:          Productivity/Multimedia/Other
Provides:       MediaInfo-gui = 0.7.7.8
Obsoletes:      MediaInfo-gui < 0.7.7.8

%description gui
This package contains a Frontend for mediainfo.

MediaInfo supplies technical and tag information about a video or
audio file.

%package -n kde4-mediainfo
Summary:        KDE4 extension for mediainfo-gui
Group:          Productivity/Multimedia/Other
Requires:       %{name}-gui

%description -n kde4-mediainfo
KDE4 context menu extension for mediainfo-gui.

%package -n kf5-mediainfo
Summary:        KF5 extension for mediainfo-gui
Group:          Productivity/Multimedia/Other
Requires:       %{name}-gui

%description -n kf5-mediainfo
KF5 context menu extension for mediainfo-gui.

%prep
%setup -q -n MediaInfo
sed -i 's/\r$//' *.html *.txt Release/*.txt
chmod 0644 *.html *.txt Release/*.txt

%build
# build CLI
pushd Project/GNU/CLI
    chmod +x autogen.sh
    ./autogen.sh
    %configure

    make %{?_smp_mflags}
popd

# now build GUI
pushd Project/GNU/GUI
    chmod +x autogen.sh
    ./autogen.sh
    %configure
    make %{?_smp_mflags}
popd

%install
pushd Project/GNU/CLI
%make_install
popd

pushd Project/GNU/GUI
%make_install
popd

# icon
install -dm 755 %{buildroot}%{_datadir}/icons/hicolor/128x128/apps
install -m 644 Source/Resource/Image/MediaInfo.png \
    %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
install -dm 755 %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -m 644 Source/Resource/Image/MediaInfo.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
install -dm 755 %{buildroot}%{_datadir}/pixmaps
install -m 644 Source/Resource/Image/MediaInfo.png \
    %{buildroot}%{_datadir}/pixmaps/mediainfo-gui.png

# menu-entry
install -dm 755 %{buildroot}/%{_datadir}/applications
install -m 644 Project/GNU/GUI/mediainfo-gui.desktop \
    %{buildroot}/%{_datadir}/applications
%suse_update_desktop_file -n %{name}-gui AudioVideo AudioVideoEditing

# hardcoded to avoid kde4-config --prefix ==> /usr
install -dm 755 %{buildroot}/%{_datadir}/kde4/services/ServiceMenus/
install -m 644 Project/GNU/GUI/mediainfo-gui.kde4.desktop \
    %{buildroot}/%{_datadir}/kde4/services/ServiceMenus/mediainfo-gui.desktop
mkdir -p %{buildroot}/%{_kf5_servicesdir}/ServiceMenus
install -m 644 Project/GNU/GUI/mediainfo-gui.kde4.desktop \
     %{buildroot}/%{_kf5_servicesdir}/ServiceMenus/mediainfo-gui.desktop

%kde_post_install

# these files are just ridicully large:
gzip -n -9 License.html
gzip -n -9 History_*.txt
%fdupes -s %{buildroot}/%{_datadir}

%files
%defattr(-,root,root,-)
%doc Release/ReadMe_CLI_Linux.txt
%doc License.html.gz History_CLI.txt.gz
%{_bindir}/mediainfo

%files gui
%defattr(-,root,root,-)
%doc Release/ReadMe_GUI_Linux.txt
%doc License.html.gz History_GUI.txt.gz
%{_bindir}/mediainfo-gui
%dir %_datadir/appdata/
%{_datadir}/appdata/mediainfo-gui.appdata.xml
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png
%{_datadir}/pixmaps/*.xpm
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/*/apps/*.svg

%files -n kde4-mediainfo
%defattr(-,root,root,-)
%dir %{_datadir}/kde4/services
%dir %{_datadir}/kde4/services/ServiceMenus
%{_datadir}/kde4/services/ServiceMenus/*.desktop
%dir %{_datadir}/apps
%dir %{_datadir}/apps/konqueror
%dir %{_datadir}/apps/konqueror/servicemenus
%{_datadir}/apps/konqueror/servicemenus/*.desktop

%files -n kf5-mediainfo
%defattr(-,root,root,-)
%dir %{_kf5_servicesdir}
%dir %{_kf5_servicesdir}/ServiceMenus
%{_kf5_servicesdir}/ServiceMenus/*.desktop

%changelog
* Thu Jun  1 2017 aloisio@gmx.com
- Update to version 0.7.96
  * Chinese (Simplified) translation updated
  * MPEG-4: display of recorded date from DV substream
  * Disabling web link as they are too much outdated
  * I505, AC-3: crash with some potentially malformed frames
  * I477, AVC: fix hang when open .mpls from some 3D BD
  * MPEG-4: does not show "1904" year is raw value is 0 (Mac/Linux)
  * Dedicated read thread disabled by default (rare dead locks)
  * #B1027, MPEG-TS: some files where detected as MPEG-TS or BDAV
    but they aren't
  * Sequence of files : frame count was wrong with sequence of
    MPEG-TS files (was count of files)
  * MXF: detection of more 608/708 with parsing of few frames in the
    middle of the file was broken
* Fri May  5 2017 aloisio@gmx.com
- Update to version 0.7.95
  * EBUCore: EBUCore 1.8 with acquisition metadata output.
  * Better support of growing files, especially when accessed by FTP
  * Matroska: better support of some broken files (high
    EBMLMaxSizeLength, padding before start of EBML)
  * EXR: showing Multipart and Deep flags
  * EXR: show image compression method
  * EBUCore: fixed display aspect ratio (was using rational)
  * EBUCore: fixed frame rate factor (was num/den instead of factor)
  * AVC: some streams with dynamic frame type were having a wrong
    frame rate
  * MPEG-4: some old AAC tracks were not correctly detected
  * Matroska: was sometimes displaying "Bit depth: Bit0" when bit
    depth is unknown
  * Nut: fix crash with some files
  * FFV1: PixelAspectRatio was an integer, switched to 3-digit
    rational
  * DTS: fix frame count
  * Dolby E: fix frame count
  * EBUCore: fix regression creating invalid XML files
  * AVC: some streams with dynamic frame type were having a wrong
    frame rate
* Sun Apr 30 2017 bwiedemann@suse.com
- call gzip -n to make build fully reproducible
* Thu Mar 30 2017 aloisio@gmx.com
- Update to version 0.7.94
  * VC-3: detection of embedded time code + VC-3: better
    support of stream with width 960 or 1440
  * VC-3: support of version 3 (a.k.a. DNxHR), including
    profile and level for version 1/2 (a.k.a. DNxHD)
  * Matroska trace feature: reduction of its size
  * MXF trace feature: reduction of its size
  * M143, MXF with Acquisition Metadata: crash fixed
  * Several crash fixes
  0.7.94
  * Matroska: detection of native FFV1 CodecID ("V_FFV1") +
    AC-3/E-AC-3: detection of Atmos inside core streams
  * AC-3/E-AC-3: slight reorganization of metadata display for
    dual mono and surround
  * AC-3/E-AC-3: "complete main" and similar info moved to
    "Service kind" dedicated line
  * AC-3/E-AC-3: more precision about how is built a stream
    (e.g. "E-AC-3+Atmos / E-AC-3" or "TrueHD+Atmos / TrueHD /
    AC-3")
  * WTV: basic detection
  * MPEG-TS: Detection of Opus
  * URL: "URLEncode" option for saying if the input should be
    URL encoded or not (default is guess = no change except if
    it contains spaces)
  * MediaTrace: for bitstreams (not bytestreams), bit offset
    was wrong
  * HLS: duration was sometimes wrong, reading only the first
    TS file duration. Now full duration is displayed
  * MPEG-TS: if stream is encrypted or invalid, level was
    sometimes not the expected one for AVC (e.g. "BaseLine@3.0"
    instead of "Baseline@3")
  * Matroska: FFV1 stream width/height was not initialized
    when Matroska track header width/height is after CodecID
  * FFV1: fix potential crash with some buggy slice headers
  * Matroska: crash in case of big attachment and CRC32 present
* Sat Mar  4 2017 jengelh@inai.de
- Trim description, avoid rhetorical questions.
- Drop export CFLAGS.. this is already done by %%configure.
* Sun Feb 26 2017 aloisio@gmx.com
- Update to version 0.7.92.1
  * Fix a performance regression in the matroska parser
  version 0.7.92
  New features:
  * #F507, MXF: detection of HLG Transfer Characteristic
  * #F508, HEVC: support of preferred_transfer_characteristics
    SEI (from HEVC/H.265 draft, preferred method for HLG in DVB)
  * MXF: parsing of AVC descriptors and crosscheck with the
    essence content
  * MP4: more AppleStoreCountry values mapped to countries, show
    the country number if unknown
  * File extension: test if the file extension correspond to the
    container format
  * AVI/WAV: test of truncated file
  * MIXML output: Format_Profile divided in Format_Profile,
    Format_Level, Format_Tier
  * ID3v2: TCAP tag is mapped to new field "PodcastCategory"
  Bug fixes:
  * MIXML output: some *_Original values were missing
  * MXF/Teletext: was not correctly detecting non subtitle
    streams
  * ID3v2: TP2 tag was incorrectly mapped to "Accompaniment",
    now mapped to "Album_Performer"
  * ID3v2: TSO2 tag was incorrectly mapped to "Performer_Sort",
    now mapped to "Album_Performer_Sort"
  * ID3v2: TCMP tag was displayed twice (2 "Compilation" lines)
  * Windows version was sometimes showing a long character
    string in Windows explorer, changed to a shorter character
    string
  version 0.7.91
  New features:
  * Add TIFF extension to Windows shell extension
  * IMF and PTX: more languages detected from file names (but
    the full list of common languages tags still need to be added)
  * IMF and PTX: support of non-standard but common "LAS" =
    "Spanish (Latin America)" language code
  * MXF: Support of color primaries, transfer characteristic,
    coding equations defined in SMPTE ST 2067-21:2016 e.g. xvYCC
    or BT.2020
  * Minor performance optimizations and cleanup (Thanks to Pavel
    Pimenov)
  * MediaTrace optimization for Matroska
  Bug fixes:
  * Fixed parsing of FFV1 v0/v1
  * PTX: fix crash due to bad parsing of some file names while
    looking for track language
  version 0.7.90
  New features:
  * #M94, WAV: support of file with a buggy RIFF header
  * Matroska: detection of segment size of zero (compatibility
    risks e.g. Windows 10 Media Player does not play such file)
  * MXF: detection of some incoherences between header and footer
  * MXF: display of Locked information
  * N19/STL: support of 48/50/60 fps content
  * N19/STL: display of time code of first frame
  * AC-3: bit depth
  * MPEG Video: CBR bitrate mode information based on vbv_delay
  * DXW: support of fake time code attribute
  Bug fixes:
  * Teletext in MPEG-TS: CodecID, format (classic teletext or
    subtitle), video delay were sometimes not displayed
  * PDF: fixed crash with some files with full analysis set
  * #B485, BMP height is negative
  * Several minor fixes
- Dropped mediainfo-rpmlintrc
* Thu Oct  6 2016 aloisio@gmx.com
- Update to version 0.7.89
  * too many changes to list, see included History_*.txt
- Added kf5-mediainfo
- Spec cleanup
* Thu Mar 27 2014 i@margueirte.su
- update version 0.7.67
  * MXF: duplicate display of some time code streams in ancillary data
  * B814, AAC: Wrong detection of audioObjectType==29
* Thu Feb 28 2013 fisiu@opensuse.org
- update to 0.7.62
  * see History_CLI.txt and History_GUI.txt for details.
* Thu Oct  4 2012 i@marguerite.su  
- update to 0.7.60
  * see History_CLI.txt and History_GUI.txt for details.
* Sat May 19 2012 seife+obs@b1-systems.com
- add autoconf/automake/libtool to BuildRequires to fix >12.1 build
* Mon Oct 24 2011 pascal.bleser@opensuse.org
- update to 0.7.50
* Wed Mar  9 2011 pascal.bleser@opensuse.org
- update to 0.7.42
* Sat Nov 13 2010 pascal.bleser@opensuse.org
- update to 0.7.36
* Sun Sep 19 2010 pascal.bleser@opensuse.org
- update to 0.7.35
* Sat Jul 31 2010 toni@links2linux.de
- update to 0.7.34
* Mon May  3 2010 toni@links2linux.de
- update to 0.7.32
* Fri Apr 16 2010 toni@links2linux.de
- update to 0.7.31
* Fri Mar 26 2010 toni@links2linux.de
- update to 0.7.30
* Tue Mar  9 2010 toni@links2linux.de
- update to 0.7.29
* Sun Feb 21 2010 toni@links2linux.de
- update to 0.7.28
* Mon Jan 11 2010 toni@links2linux.de
- update to 0.7.27
* Wed Dec 23 2009 toni@links2linux.de
- update to 0.7.26
* Fri Nov 20 2009 toni@links2linux.de
- update to 0.7.25
* Fri Oct 30 2009 toni@links2linux.de
- update to 0.7.24
* Tue Oct 27 2009 toni@links2linux.de
- update to 0.7.23
* Tue Oct 13 2009 toni@links2linux.de
- update to 0.7.19
* Mon Jun 22 2009 toni@links2linux.de
- update to 0.7.17
* Wed May 20 2009 toni@links2linux.de
- update to 0.7.16
* Thu Apr 30 2009 toni@links2linux.de
- update to 0.7.15
* Fri Apr 17 2009 toni@links2linux.de
- update to 0.7.14
* Sun Apr  5 2009 toni@links2linux.de
- update to 0.7.13
* Sat Apr  4 2009 toni@links2linux.de
- redowngrade to 0.7.12
* Fri Apr  3 2009 toni@links2linux.de
- update to 0.7.13
* Fri Mar 20 2009 toni@links2linux.de
- update to 0.7.12
* Fri Feb 13 2009 toni@links2linux.de
- update to 0.7.11
- added sub-package kde4-mediainfo
* Fri Jan 30 2009 toni@links2linux.de
- update to 0.7.10
* Fri Jan 23 2009 toni@links2linux.de
- update to 0.7.9
* Wed Dec 10 2008 toni@links2linux.de
- added defattr in subpackage konqueror
- corrected icon-name for desktop-entry
* Tue Dec  9 2008 toni@links2linux.de
- update to 0.7.8
- added sub-package for konqueror extension
* Tue Nov 18 2008 toni@links2linux.de
- changed package layout, reflecting new upstream tar-balls
- rebuild using libzen(-devel) and libmediainfo(-devel)
- renamed package to mediainfo (obsoletes MediaInfo)
- added subpackage gui (obsoletes MediaInfo-gui)
- using desktop file from tarball (includes french localisation)
* Mon Nov 10 2008 toni@links2linux.de
- update to 0.7.7.8
* Fri Oct 17 2008 toni@links2linux.de
- update to 0.7.7.7
* Fri Sep 12 2008 toni@links2linux.de
- update to 0.7.7.6
* Fri Aug 22 2008 toni@links2linux.de
- update to 0.7.7.5
* Fri Jul 11 2008 toni@links2linux.de
- update to 0.7.7.4
* Thu Jun 26 2008 toni@links2linux.de
- update to 0.7.7.3
* Fri Jun 13 2008 toni@links2linux.de
- update to 0.7.7.2
* Fri May 30 2008 toni@links2linux.de
- update to 0.7.7.1
* Fri May 16 2008 toni@links2linux.de
- update to 0.7.7.0
* Mon Apr 28 2008 toni@links2linux.de
- update to 0.7.6.4
* Sat Apr 12 2008 toni@links2linux.de
- update to 0.7.6.3
* Fri Mar 28 2008 toni@links2linux.de
- update to 0.7.6.2
* Fri Mar 14 2008 toni@links2linux.de
- update to 0.7.6.1
* Fri Feb 29 2008 toni@links2linux.de
- update to 0.7.6.0
* Fri Feb  8 2008 toni@links2linux.de
- update to 0.7.5.9
* Fri Feb  1 2008 toni@links2linux.de
- update to 0.7.5.8
* Wed Jan  9 2008 toni@links2linux.de
- update to 0.7.5.7
* Mon Dec 10 2007 toni@links2linux.de
- update to 0.7.5.6
* Fri Nov  9 2007 toni@links2linux.de
- update to 0.7.5.5
- libMatroska and libEbml are no more used
- The script now look for /usr/lib/libz.a and /usr/include/zlib.h before
  downloading at the official zlib website.
  - -> If you have the development package of zlib, no more downloads!
* Sat Nov  3 2007 toni@links2linux.de
- update to 0.7.5.4
* Fri Nov  2 2007 toni@links2linux.de
- initial build 0.7.5.3
